#
# spec file for package dpdk
#
# Copyright (c) 2020 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#
# needssslcertforbuild


%define flavor thunderx%{nil}
%define aarch64_machine2 armv8a
%define exclusive_arch aarch64 x86_64 ppc64le
%define name_tag %{nil}
%define summary_tag %{nil}
%if "%flavor" == "thunderx"
%define name_tag -thunderx
%define summary_tag (thunderx)
%define aarch64_machine2 thunderx
%define exclusive_arch aarch64
%endif
%define machine native
%define machine2 default
%ifarch x86_64
%define machine native
%define target x86_64-%{machine}-linuxapp-gcc
%endif
%ifarch aarch64
%define machine2 %aarch64_machine2
%define target arm64-%{machine2}-linuxapp-gcc
%endif
%ifarch ppc64le
%define machine2 power8
%define target ppc_64-%{machine2}-linuxapp-gcc
%endif
# This is in sync with <src>/ABI_VERSION
# TODO: automate this sync
%define maj 20
%define min 0
%define lname libdpdk-%{maj}_%{min}
%bcond_without shared
# Add option to build without examples
%bcond_without examples
# Add option to build without tools
%bcond_without tools
Name:           dpdk%{name_tag}
Version:        19.11.4
Release:        lp152.2.8.1
Summary:        Set of libraries and drivers for fast packet processing
License:        BSD-3-Clause AND GPL-2.0-only AND LGPL-2.1-only
Group:          System/Libraries
URL:            http://dpdk.org
Source:         http://fast.dpdk.org/rel/dpdk-%{version}.tar.xz
Source1:        preamble
Patch1:         0001-fix-cpu-compatibility.patch
Patch2:         0001-vhost-crypto-fix-pool-allocation.patch
Patch3:         0002-vhost-crypto-fix-incorrect-descriptor-deduction.patch
Patch4:         0003-vhost-crypto-fix-missed-request-check-for-copy-mode.patch
Patch5:         0004-vhost-crypto-fix-incorrect-write-back-source.patch
Patch6:         0005-vhost-crypto-fix-data-length-check.patch
Patch7:         0006-vhost-crypto-fix-possible-TOCTOU-attack.patch
BuildRequires:  doxygen
BuildRequires:  fdupes
BuildRequires:  libelf-devel
BuildRequires:  libmnl-devel
BuildRequires:  libnuma-devel
BuildRequires:  libpcap-devel
BuildRequires:  pesign-obs-integration
BuildRequires:  zlib-devel
Conflicts:      dpdk-any
Provides:       dpdk-any = %{version}
ExclusiveArch:  %exclusive_arch
%if 0%{?sle_version} >= 120400
BuildRequires:  rdma-core-devel
%endif

%description
The Data Plane Development Kit is a set of libraries and drivers for
fast packet processing in the user space.

%package devel
Summary:        Data Plane Development Kit development files %{summary_tag}
Group:          Development/Libraries/C and C++
Requires:       %{lname} = %{version}
Conflicts:      dpdk-any-devel
Provides:       dpdk-any-devel = %{version}

%description devel
This package contains the headers and other files needed for developing
applications with the Data Plane Development Kit.

%package -n %{lname}
Summary:        Data Plane Development Kit runtime libraries %{summary_tag}
Group:          Development/Libraries/C and C++
Provides:       %{lname}-any = %{version}

%description -n %{lname}
This package contains the runtime libraries needed for 3rd party application
to use the Data Plane Development Kit.

%package doc
Summary:        Data Plane Development Kit API documentation %{summary_tag}
Group:          System/Libraries
Conflicts:      dpdk-any-doc
Provides:       dpdk-any-doc = %{version}
BuildArch:      noarch

%description doc
API programming documentation for the Data Plane Development Kit.

%if %{with tools}
%package tools
Summary:        Tools for setting up Data Plane Development Kit environment %{summary_tag}
Group:          System/Libraries
Requires:       %{name} = %{version}
Requires:       findutils
Requires:       iproute
Requires:       kmod
Requires:       pciutils
Conflicts:      dpdk-any-tools
Provides:       dpdk-any-tools = %{version}

%description tools
This package contains tools for setting up Data Plane Development Kit environment
%endif

%if %{with examples}
%package examples
Summary:        Data Plane Development Kit example applications %{summary_tag}
Group:          System/Libraries
BuildRequires:  libvirt-devel
Conflicts:      dpdk-any-examples
Provides:       dpdk-any-examples = %{version}

%description examples
Example applications utilizing the Data Plane Development Kit, such
as L2 and L3 forwarding.
%endif

%package kmp
Summary:        DPDK KNI kernel module %{summary_tag}
Group:          System/Kernel
BuildRequires:  %{kernel_module_package_buildreqs}
Conflicts:      dpdk-any-kmp
%suse_kernel_module_package -p %{_sourcedir}/preamble pae 64kb

%description kmp
The DPDK Kernel NIC Interface (KNI) allows userspace applications access to the Linux* control plane.

%define sdkdir  %{_datadir}/dpdk
%define docdir  %{_docdir}/dpdk
%define incdir %{_includedir}/dpdk
%define pmddir %{_libdir}/dpdk-pmds-%{maj}.%{min}

%prep
# can't use %{name} because of dpdk-thunderx
%setup -q -n dpdk-stable-%{version}
%patch1 -p1 -z .init
%patch2 -p1 -z .init
%patch3 -p1 -z .init
%patch4 -p1 -z .init
%patch5 -p1 -z .init
%patch6 -p1 -z .init
%patch7 -p1 -z .init

# This fixes CROSS compilation (broken) in the mk file for ThunderX
sed -i '/^CROSS /s/^/#/'  mk/machine/thunderx/rte.vars.mk

# Verify ABI
[ "$(cat ABI_VERSION)" = "%{maj}.%{min}" ] || exit 1

%build

cp mk/machine/armv8a/rte.vars.mk mk/machine/thunderx

# set up a method for modifying the resulting .config file
function setconf() {
	if grep -q ^$1= $3/.config; then
		sed -i "s:^$1=.*$:$1=$2:g" $3/.config
	else
		echo $1=$2 >> $3/.config
	fi
}

function setdefaultconf()
{
	# Remove the below once upstream fixes the DPAA for NXP ARM
	setconf CONFIG_RTE_LIBRTE_DPAA_BUS n $1
	setconf CONFIG_RTE_LIBRTE_DPAA_MEMPOOL n $1
	setconf CONFIG_RTE_LIBRTE_DPAA_PMD n $1
	setconf CONFIG_RTE_LIBRTE_PMD_CAAM_JR n $1
	setconf CONFIG_RTE_LIBRTE_PMD_DPAA_SEC n $1
	setconf CONFIG_RTE_LIBRTE_PMD_DPAA_EVENTDEV n $1
	%ifarch aarch64
	setconf CONFIG_RTE_LIBRTE_PFE_PMD n $1
	%endif

	setconf CONFIG_RTE_MACHINE '"%{machine2}"' $1
	# Disable experimental features
	setconf CONFIG_RTE_NEXT_ABI n $1

	# Enable automatic driver loading from this path
	setconf CONFIG_RTE_EAL_PMD_PATH '"%{pmddir}"' $1

	setconf CONFIG_RTE_LIBRTE_BNX2X_PMD y $1
	setconf CONFIG_RTE_LIBRTE_BNX2X_MF_SUPPORT y $1
	setconf CONFIG_RTE_LIBRTE_PMD_PCAP y $1
	setconf CONFIG_RTE_LIBRTE_VHOST_NUMA y $1
%if 0%{?sle_version} >= 120400
	setconf CONFIG_RTE_LIBRTE_MLX5_PMD y $1
	setconf CONFIG_RTE_LIBRTE_MLX4_PMD y $1
%endif
	setconf CONFIG_RTE_EAL_IGB_UIO n $1
	setconf CONFIG_RTE_KNI_KMOD n $1

	%if %{with shared}
	setconf CONFIG_RTE_BUILD_SHARED_LIB y $1
	%endif

	%ifarch aarch64 ppc64le
	setconf CONFIG_RTE_LIBRTE_DISTRIBUTOR n $1
	%endif
	%ifarch ppc64le
	setconf CONFIG_RTE_LIBRTE_PMD_RING n $1
	setconf CONFIG_RTE_LIBRTE_IXGBE_PMD n $1
	setconf CONFIG_RTE_LIBRTE_POWER n $1
	%endif
}
# In case dpdk-devel is installed, we should ignore its hints about the SDK directories
unset RTE_SDK RTE_INCLUDE RTE_TARGET

export EXTRA_CFLAGS="%{optflags} -Wformat -fPIC -U_FORTIFY_SOURCE"

# DPDK defaults to using builder-specific compiler flags.  However,
# the config has been changed by specifying CONFIG_RTE_MACHINE=default
# in order to build for a more generic host.  NOTE: It is possible that
# the compiler flags used still won't work for all Fedora-supported
# machines, but runtime checks in DPDK will catch those situations.

make V=1 O=%{target} T=%{target} %{?_smp_mflags} config
setdefaultconf %{target}

export EXTRA_CFLAGS='-DVERSION=\"%{version}\"'
for flavor in %{flavors_to_build}; do
	export RTE_KERNELDIR=%{_prefix}/src/linux-obj/%{_target_cpu}/$flavor
	make V=1 O=%{target}-$flavor T=%{target} %{?_smp_mflags} config
	setdefaultconf %{target}-$flavor
	setconf CONFIG_RTE_EAL_IGB_UIO y %{target}-$flavor
	setconf CONFIG_RTE_KNI_KMOD y %{target}-$flavor
	cd  %{target}-$flavor
	make V=1 %{?_smp_mflags}
	cd -
done

make V=1 O=%{target} %{?_smp_mflags}
make V=1 O=%{target} %{?_smp_mflags} doc-api-html

%if %{with examples}
make V=1 O=%{target}/examples T=%{target} %{?_smp_mflags} examples
%endif

%install
# export needed for kmp package
export EXTRA_CFLAGS='-DVERSION=\"%{version}\"'
export INSTALL_MOD_PATH=%{buildroot}
export INSTALL_MOD_DIR=updates
export BRP_PESIGN_FILES="*.ko"

for flavor in %{flavors_to_build}; do
	cd  %{target}-$flavor
	export RTE_KERNELDIR=%{_prefix}/src/linux-obj/%{_target_cpu}/$flavor
	dir=%{_prefix}/src/linux-obj/%{_target_cpu}/$flavor
	krel=$(make -s -C "$dir" kernelrelease)
	mkdir -p %{buildroot}/lib/modules/$krel/extra/dpdk/
	#make install expects same kernel for build and target, lets copy it manually
	install -m644 ../%{target}-$flavor/kmod/*.ko %{buildroot}/lib/modules/$krel/extra/dpdk/
	cd -
done
# In case dpdk-devel is installed
unset RTE_SDK RTE_INCLUDE RTE_TARGET

%make_install O=%{target} prefix=%{_usr} libdir=%{_libdir}

%if ! %{with tools}
rm -rf %{buildroot}%{sdkdir}/usertools/
rm -rf %{buildroot}%{_sbindir}/dpdk_nic_bind
%endif
rm -f %{buildroot}%{sdkdir}/usertools/setup.sh
#TODO pip elftools has issues to fix
rm -rf %{buildroot}%{_bindir}/dpdk-pmdinfo

%if %{with examples}
find %{target}/examples/ -name "*.map" | xargs rm -f
for f in %{target}/examples/*/%{target}/app/*; do
    bn=`basename ${f}`
    cp -p ${f} %{buildroot}%{_bindir}/dpdk_example_${bn}
done
%endif

# Create a driver directory with symlinks to all pmds
mkdir -p %{buildroot}/%{pmddir}
for f in %{buildroot}/%{_libdir}/*_pmd_*.so.*; do
    bn=$(basename ${f})
    ln -s ../${bn} %{buildroot}%{pmddir}/${bn}
done
#mempool is a driver now from 16.07
mkdir -p %{buildroot}/%{pmddir}
for f in %{buildroot}/%{_libdir}/*_mempool_*.so.*; do
    bn=$(basename ${f})
    ln -s ../${bn} %{buildroot}%{pmddir}/${bn}
done

# Setup RTE_SDK environment as expected by apps etc
mkdir -p %{buildroot}/%{_sysconfdir}/profile.d
cat << EOF > %{buildroot}/%{_sysconfdir}/profile.d/dpdk-sdk-%{_arch}.sh
if [ -z "\${RTE_SDK}" ]; then
    export RTE_SDK="%{sdkdir}"
    export RTE_TARGET="%{target}"
    export RTE_INCLUDE="%{incdir}"
fi
EOF

cat << EOF > %{buildroot}/%{_sysconfdir}/profile.d/dpdk-sdk-%{_arch}.csh
if ( ! \${?RTE_SDK} ) then
    setenv RTE_SDK "%{sdkdir}"
    setenv RTE_TARGET "%{target}"
    setenv RTE_INCLUDE "%{incdir}"
endif
EOF

# Fixup target machine mismatch
sed -i -e 's:-%{machine}-:-%{machine2}-:g' %{buildroot}/%{_sysconfdir}/profile.d/dpdk-sdk*

#doc
mkdir %{buildroot}%{_docdir}/
mv   %{buildroot}%{_datadir}/doc/dpdk %{buildroot}%{_docdir}/

ln -s %{_bindir}/dpdk-procinfo %{buildroot}%{_bindir}/dpdk_proc_info
ln -s %{_sbindir}/dpdk-devbind %{buildroot}%{_sbindir}/dpdk_nic_bind

# Remove duplicates
%fdupes %{buildroot}/%{_prefix}

%post devel -p /sbin/ldconfig
%postun devel -p /sbin/ldconfig
%post -n %{lname} -p /sbin/ldconfig
%postun -n %{lname} -p /sbin/ldconfig

%files
%defattr(-,root,root)
# BSD
%{_bindir}/testpmd
%{_bindir}/testbbdev
%{_bindir}/testsad
%{_bindir}/dpdk-procinfo
%{_bindir}/dpdk_proc_info
%{_bindir}/dpdk-pdump

%files -n %{lname}
%defattr(-,root,root)
%if %{with shared}
%{_libdir}/*.so.*
%{pmddir}
%endif

%files doc
%defattr(-,root,root)
#BSD
%docdir
%doc license/gpl-2.0.txt license/lgpl-2.1.txt

%files devel
%defattr(-,root,root)
#BSD
%{incdir}/
%{sdkdir}
%if %{with tools}
%exclude %{sdkdir}/usertools/
%endif
%if %{with examples}
%exclude %{sdkdir}/examples/
%endif
%{_sysconfdir}/profile.d/dpdk-sdk-*.*
%if ! %{with shared}
%{_libdir}/*.a
%else
%{_libdir}/*.so
%endif

%if %{with tools}
%files tools
%defattr(-,root,root)
%{sdkdir}/usertools/
%{_sbindir}/dpdk-devbind
%{_sbindir}/dpdk_nic_bind
%{_bindir}/dpdk-test-eventdev
%{_bindir}/dpdk-test-compress-perf
%{_bindir}/dpdk-test-crypto-perf
%endif

%if %{with examples}
%files examples
%defattr(-,root,root)
%{_bindir}/dpdk_example_*
%doc %{sdkdir}/examples
%endif

%changelog
* Fri Sep 18 2020 Jaime Caamaño Ruiz <jcaamano@suse.com>
- Update to 19.11.4. For a list of fixes check:
  https://doc.dpdk.org/guides-19.11/rel_notes/release_19_11.html#id8
- Add patches to fix vulnerability where malicious guest can harm the host
  using vhost crypto, this includes executing code in host (VM Escape),
  reading host application memory space to guest and causing partially
  denial of service in the host (CVE-2020-14374,CVE-2020-14375,CVE-2020-14376,
  CVE-2020-14377,CVE-2020-14378bsc#1176590).
  * 0001-vhost-crypto-fix-pool-allocation.patch
  * 0002-vhost-crypto-fix-incorrect-descriptor-deduction.patch
  * 0003-vhost-crypto-fix-missed-request-check-for-copy-mode.patch
  * 0004-vhost-crypto-fix-incorrect-write-back-source.patch
  * 0005-vhost-crypto-fix-data-length-check.patch
  * 0006-vhost-crypto-fix-possible-TOCTOU-attack.patch
* Tue Aug 11 2020 Dirk Mueller <dmueller@suse.com>
- update to v19.11.3:
    app/crypto-perf: fix display of sample test vector
    app/eventdev: check Tx adapter service ID
    app: fix usage help of options separated by dashes
    app/pipeline: fix build with gcc 10
    app: remove extra new line after link duplex
    app/testpmd: add parsing for QinQ VLAN headers
    app/testpmd: fix DCB set
    app/testpmd: fix memory failure handling for i40e DDP
    app/testpmd: fix PPPoE flow command
    app/testpmd: fix statistics after reset
    baseband/turbo_sw: fix exposed LLR decimals assumption
    bbdev: fix doxygen comments
    build: disable gcc 10 zero-length-bounds warning
    build: fix linker warnings with clang on Windows
    build: support MinGW-w64 with Meson
    buildtools: get static mlx dependencies for meson
    bus/fslmc: fix dereferencing null pointer
    bus/fslmc: fix size of qman fq descriptor
    bus/pci: fix devargs on probing again
    bus/pci: fix UIO resource access from secondary process
    bus/vmbus: fix comment spelling
    ci: fix telemetry dependency in Travis
    common/iavf: update copyright
    common/mlx5: fix build with -fno-common
    common/mlx5: fix build with rdma-core 21
    common/mlx5: fix netlink buffer allocation from stack
    common/mlx5: fix umem buffer alignment
    common/octeontx: fix gcc 9.1 ABI break
    common/qat: fix GEN3 marketing name
    contigmem: cleanup properly when load fails
    crypto/caam_jr: fix check of file descriptors
    crypto/caam_jr: fix IRQ functions return type
    crypto/ccp: fix fd leak on probe failure
    cryptodev: add asymmetric session-less feature name
    cryptodev: fix missing device id range checking
    cryptodev: fix SHA-1 digest enum comment
    crypto/kasumi: fix extern declaration
    crypto/nitrox: fix CSR register address generation
    crypto/nitrox: fix oversized device name
    crypto/octeontx2: fix build with gcc 10
    crypto/openssl: fix out-of-place encryption
    crypto/qat: fix cipher descriptor for ZUC and SNOW
    crypto/qat: support plain SHA1..SHA512 hashes
    devtools: fix symbol map change check
    doc: add i40e limitation for flow director
    doc: add NASM installation steps
    doc: fix API index
    doc: fix build issue in ABI guide
    doc: fix build with doxygen 1.8.18
    doc: fix default symbol binding in ABI guide
    doc: fix log level example in Linux guide
    doc: fix LTO config option
    doc: fix matrix CSS for recent sphinx
    doc: fix multicast filter feature announcement
    doc: fix number of failsafe sub-devices
    doc: fix reference in ABI guide
    doc: fix sphinx compatibility
    doc: fix typo in contributors guide
    doc: fix typo in contributors guide
    doc: fix typos in ABI policy
    doc: prefer https when pointing to dpdk.org
    drivers: add crypto as dependency for event drivers
    drivers/crypto: disable gcc 10 no-common errors
    drivers/crypto: fix build with make 4.3
    drivers/crypto: fix log type variables for -fno-common
    drivers: fix log type variables for -fno-common
    eal/arm64: fix precise TSC
    eal: fix C++17 compilation
    eal: fix comments spelling
    eal: fix log message print for regex
    eal: fix PRNG init with HPET enabled
    eal: fix typo in endian conversion macros
    eal/freebsd: fix queuing duplicate alarm callbacks
    eal/ppc: fix bool type after altivec include
    eal/ppc: fix build with gcc 9.3
    eal/x86: ignore gcc 10 stringop-overflow warnings
    ethdev: fix build when vtune profiling is on
    ethdev: fix spelling
    eventdev: fix probe and remove for secondary process
    event/dsw: avoid reusing previously recorded events
    event/dsw: fix enqueue burst return value
    event/dsw: remove redundant control ring poll
    event/dsw: remove unnecessary read barrier
    event/octeontx2: fix build for O1 optimization
    event/octeontx2: fix queue removal from Rx adapter
    examples/eventdev: fix build with gcc 10
    examples/eventdev: fix crash on exit
    examples/fips_validation: fix parsing of algorithms
    examples/ip_pipeline: remove check of null response
    examples/ipsec-gw: fix gcc 10 maybe-uninitialized warning
    examples/kni: fix crash during MTU set
    examples/kni: fix MTU change to setup Tx queue
    examples/l2fwd-keepalive: fix mbuf pool size
    examples/qos_sched: fix build with gcc 10
    examples: remove extra new line after link duplex
    examples/vhost_blk: fix build with gcc 10
    examples/vmdq: fix output of pools/queues
    examples/vmdq: fix RSS configuration
    examples/vm_power: drop Unix path limit redefinition
    examples/vm_power: fix build with -fno-common
    fib: fix headers for C++ support
    fix same typo in multiple places
    fix various typos found by Lintian
    ipsec: check SAD lookup error
    ipsec: fix build dependency on hash lib
    kvargs: fix buffer overflow when parsing list
    kvargs: fix invalid token parsing on FreeBSD
    kvargs: fix strcmp helper documentation
    log: fix level picked with globbing on type register
    lpm6: fix comments spelling
    lpm6: fix size of tbl8 group
    mem: fix overflow on allocation
    mem: mark pages as not accessed when freeing memory
    mem: mark pages as not accessed when reserving VA
    mempool/dpaa2: install missing header with meson
    mempool/octeontx2: fix build for gcc O1 optimization
    mempool: remove inline functions from export list
    mem: preallocate VA space in no-huge mode
    mk: fix static linkage of mlx dependency
    net/avp: fix gcc 10 maybe-uninitialized warning
    net/bnxt: do not use PMD log type
    net/bnxt: fix error log for command timeout
    net/bnxt: fix FW version query
    net/bnxt: fix HWRM command during FW reset
    net/bnxt: fix max ring count
    net/bnxt: fix memory leak during queue restart
    net/bnxt: fix number of TQM ring
    net/bnxt: fix port start failure handling
    net/bnxt: fix possible stack smashing
    net/bnxt: fix Rx ring producer index
    net/bnxt: fix storing MAC address twice
    net/bnxt: fix TQM ring context memory size
    net/bnxt: fix using RSS config struct
    net/bnxt: fix VLAN add when port is stopped
    net/bnxt: fix VNIC Rx queue count on VNIC free
    net/bnxt: use true/false for bool types
    net/dpaa2: fix 10G port negotiation
    net/dpaa2: fix congestion ID for multiple traffic classes
    net/dpaa: use dynamic log type
    net/e1000: fix port hotplug for multi-process
    net/ena/base: fix documentation of functions
    net/ena/base: fix indentation in CQ polling
    net/ena/base: fix indentation of multiple defines
    net/ena/base: fix testing for supported hash function
    net/ena/base: make allocation macros thread-safe
    net/ena/base: prevent allocation of zero sized memory
    net/ena: fix build for O1 optimization
    net/ena: set IO ring size to valid value
    net/enetc: fix Rx lock-up
    net/enic: fix flow action reordering
    net/failsafe: fix fd leak
    net/hinic: allocate IO memory with socket id
    net/hinic/base: fix PF firmware hot-active problem
    net/hinic/base: fix port start during FW hot update
    net/hinic: fix LRO
    net/hinic: fix queues resource free
    net/hinic: fix repeating cable log and length check
    net/hinic: fix snprintf length of cable info
    net/hinic: fix TSO
    net/hinic: fix Tx mbuf length while copying
    net/hns3: add free threshold in Rx
    net/hns3: add RSS hash offload to capabilities
    net/hns3: clear residual flow rules on init
    net/hns3: fix configuring illegal VLAN PVID
    net/hns3: fix configuring RSS hash when rules are flushed
    net/hns3: fix crash when flushing RSS flow rules with FLR
    net/hns3: fix default error code of command interface
    net/hns3: fix default VLAN filter configuration for PF
    net/hns3: fix mailbox opcode data type
    net/hns3: fix MSI-X interrupt during initialization
    net/hns3: fix packets offload features flags in Rx
    net/hns3: fix promiscuous mode for PF
    net/hns3: fix return value of setting VLAN offload
    net/hns3: fix return value when clearing statistics
    net/hns3: fix RSS indirection table configuration
    net/hns3: fix RSS key length
    net/hns3: fix Rx interrupt after reset
    net/hns3: fix status after repeated resets
    net/hns3: fix Tx interrupt when enabling Rx interrupt
    net/hns3: fix VLAN filter when setting promisucous mode
    net/hns3: fix VLAN PVID when configuring device
    net/hns3: reduce judgements of free Tx ring space
    net/hns3: remove one IO barrier in Rx
    net/hns3: remove unnecessary assignments in Tx
    net/hns3: replace memory barrier with data dependency order
    net/hns3: support different numbers of Rx and Tx queues
    net/hns3: support Rx interrupt
    net/i40e/base: update copyright
    net/i40e: fix flow director enabling
    net/i40e: fix flow director for ARP packets
    net/i40e: fix flow director initialisation
    net/i40e: fix flush of flow director filter
    net/i40e: fix queue region in RSS flow
    net/i40e: fix queue related exception handling
    net/i40e: fix setting L2TAG
    net/i40e: fix wild pointer
    net/i40e: fix X722 performance
    net/i40e: relax barrier in Tx
    net/i40e: relax barrier in Tx for NEON
    net/iavf: fix link speed
    net/iavf: fix setting L2TAG
    net/iavf: fix stats query error code
    net/ice: add action number check for switch
    net/ice/base: check memory pointer before copying
    net/ice/base: fix binary order for GTPU filter
    net/ice/base: fix MAC write command
    net/ice/base: fix uninitialized stack variables
    net/ice/base: minor fixes
    net/ice/base: read PSM clock frequency from register
    net/ice/base: remove unused code in switch rule
    net/ice/base: update copyright
    net/ice: change default tunnel type
    net/ice: fix crash in switch filter
    net/ice: fix hash flow crash
    net/ice: fix input set of VLAN item
    net/ice: fix RSS advanced rule
    net/ice: fix RSS for GTPU
    net/ice: fix setting L2TAG
    net/ice: fix variable initialization
    net/ice: remove bulk alloc option
    net/ice: remove unnecessary variable
    net/ice: support mark only action for flow director
    net/ipn3ke: use control thread to check link status
    net/ixgbe/base: update copyright
    net/ixgbe: check driver type in MACsec API
    net/ixgbe: fix link state timing on fiber ports
    net/ixgbe: fix link status after port reset
    net/ixgbe: fix link status inconsistencies
    net/ixgbe: fix link status synchronization on BSD
    net/ixgbe: fix resource leak after thread exits normally
    net/ixgbe: fix statistics in flow control mode
    net/memif: fix init when already connected
    net/memif: fix resource leak
    net/mlx4: fix build with -fno-common
    net/mlx4: fix drop queue error handling
    net/mlx5: add device parameter for MPRQ stride size
    net/mlx5: add multi-segment packets in MPRQ mode
    net/mlx5: enable MPRQ multi-stride operations
    net/mlx5: fix actions validation on root table
    net/mlx5: fix assert in doorbell lookup
    net/mlx5: fix assert in dynamic metadata handling
    net/mlx5: fix assert in modify converting
    net/mlx5: fix build with separate glue lib for dlopen
    net/mlx5: fix call to modify action without init item
    net/mlx5: fix counter container usage
    net/mlx5: fix crash when releasing meter table
    net/mlx5: fix CVLAN tag set in IP item translation
    net/mlx5: fix doorbell bitmap management offsets
    net/mlx5: fix gcc 10 enum-conversion warning
    net/mlx5: fix header modify action validation
    net/mlx5: fix imissed counter overflow
    net/mlx5: fix jump table leak
    net/mlx5: fix mask used for IPv6 item validation
    net/mlx5: fix matching for UDP tunnels with Verbs
    net/mlx5: fix match on empty VLAN item in DV mode
    net/mlx5: fix metadata for compressed Rx CQEs
    net/mlx5: fix meter color register consideration
    net/mlx5: fix meter suffix table leak
    net/mlx5: fix packet length assert in MPRQ
    net/mlx5: fix push VLAN action to use item info
    net/mlx5: fix RSS enablement
    net/mlx5: fix RSS key copy to TIR context
    net/mlx5: fix Tx queue release debug log timing
    net/mlx5: fix validation of push VLAN without full mask
    net/mlx5: fix validation of VXLAN/VXLAN-GPE specs
    net/mlx5: fix VLAN flow action with wildcard VLAN item
    net/mlx5: fix VLAN ID check
    net/mlx5: fix VLAN PCP item calculation
    net/mlx5: fix zero metadata action
    net/mlx5: fix zero value validation for metadata
    net/mlx5: improve logging of MPRQ selection
    net/mlx5: reduce Tx completion index memory loads
    net/mlx5: set dynamic flow metadata in Rx queues
    net/mlx5: update VLAN and encap actions validation
    net/mlx5: use open/read/close for ib stats query
    net/mvneta: do not use PMD log type
    net/mvpp2: fix build with gcc 10
    net/netvsc: avoid possible live lock
    net/netvsc: do not configure RSS if disabled
    net/netvsc: do RSS across Rx queue only
    net/netvsc: fix comment spelling
    net/netvsc: fix memory free on device close
    net/netvsc: handle Rx packets during multi-channel setup
    net/netvsc: handle Tx completions based on burst size
    net/netvsc: propagate descriptor limits from VF
    net/netvsc: remove process event optimization
    net/netvsc: split send buffers from Tx descriptors
    net/nfp: fix dangling pointer on probe failure
    net/nfp: fix log format specifiers
    net/null: fix secondary burst function selection
    net/null: remove redundant check
    net/octeontx2: disable unnecessary error interrupts
    net/octeontx2: enable error and RAS interrupt in configure
    net/octeontx2: fix buffer size assignment
    net/octeontx2: fix device configuration sequence
    net/octeontx2: fix link information for loopback port
    net/octeontx: fix dangling pointer on init failure
    net/octeontx: fix meson build for disabled drivers
    net/pfe: do not use PMD log type
    net/pfe: fix double free of MAC address
    net/qede: fix link state configuration
    net/qede: fix port reconfiguration
    net/ring: fix device pointer on allocation
    net/sfc/base: fix build when EVB is enabled
    net/sfc/base: fix manual filter delete in EF10
    net/sfc/base: handle manual and auto filter clashes in EF10
    net/sfc/base: reduce filter priorities to implemented only
    net/sfc/base: refactor filter lookup loop in EF10
    net/sfc/base: reject automatic filter creation by users
    net/sfc/base: use simpler EF10 family conditional check
    net/sfc/base: use simpler EF10 family run-time checks
    net/sfc: fix initialization error path
    net/sfc: fix promiscuous and allmulticast toggles errors
    net/sfc: fix reported promiscuous/multicast mode
    net/sfc: fix Rx queue start failure path
    net/sfc: set priority of created filters to manual
    net/softnic: fix memory leak for thread
    net/softnic: fix resource leak for pipeline
    net/tap: do not use PMD log type
    net/tap: fix check for mbuf number of segment
    net/tap: fix crash in flow destroy
    net/tap: fix fd leak on creation failure
    net/tap: fix file close on remove
    net/tap: fix mbuf and mem leak during queue release
    net/tap: fix mbuf double free when writev fails
    net/tap: fix queues fd check before close
    net/tap: fix unexpected link handler
    net/tap: remove unused assert
    net/thunderx: use dynamic log type
    net/vhost: fix potential memory leak on close
    net/virtio: do not use PMD log type
    net/virtio: fix crash when device reconnecting
    net/virtio: fix outdated comment
    net/virtio: fix unexpected event after reconnect
    net/virtio-user: fix devargs parsing
    net/vmxnet3: fix RSS setting on v4
    net/vmxnet3: handle bad host framing
    pci: accept 32-bit domain numbers
    pci: fix build on FreeBSD
    pci: fix build on ppc
    pci: reject negative values in PCI id
    pci: remove unneeded includes in public header file
    remove references to private PCI probe function
    Revert “common/qat: fix GEN3 marketing name”
    Revert “net/bnxt: fix number of TQM ring”
    Revert “net/bnxt: fix TQM ring context memory size”
    security: fix crash at accessing non-implemented ops
    security: fix return types in documentation
    security: fix session counter
    security: fix verification of parameters
    service: fix crash on exit
    service: fix identification of service running on other lcore
    service: fix race condition for MT unsafe service
    service: remove rte prefix from static functions
    telemetry: fix port stats retrieval
    test/crypto: fix flag check
    test/crypto: fix statistics case
    test: fix build with gcc 10
    test/flow_classify: enable multi-sockets system
    test/ipsec: fix crash in session destroy
    test/kvargs: fix invalid cases check
    test/kvargs: fix to consider empty elements as valid
    test: load drivers when required
    test: remove redundant macro
    test: skip some subtests in no-huge mode
    timer: protect initialization with lock
    usertools: check for pci.ids in /usr/share/misc
    vfio: fix race condition with sysfs
    vfio: fix use after free with multiprocess
    vhost/crypto: add missing user protocol flag
    vhost: fix packed ring zero-copy
    vhost: fix peer close check
    vhost: fix shadowed descriptors not flushed
    vhost: fix shadow update
    vhost: fix zero-copy server mode
    vhost: handle mbuf allocation failure
    vhost: make IOTLB cache name unique among processes
    vhost: prevent zero-copy with incompatible client mode
    vhost: remove unused variable
- remove the security backport patches as they're already included
  upstream:
  * 0001-vhost-check-log-mmap-offset-and-size-overflow.patch
  * 0002-vhost-fix-vring-index-check.patch
  * 0003-vhost-crypto-validate-keys-lengths.patch
  * 0004-vhost-fix-translated-address-not-checked.patch
  * 0005-vhost-fix-potential-memory-space-leak.patch
  * 0006-vhost-fix-potential-fd-leak.patch
* Tue May 19 2020 Jaime Caamaño Ruiz <jcaamano@suse.com>
- Add patches to fix vulnerability where malicious guest/container can
  cause resource leak resulting a Denial-of-Service, or memory corruption
  and crash, or information leak in vhost-user backend application
  (bsc#1171477, CVE-2020-10722, CVE-2020-10723, CVE-2020-10724,
  CVE-2020-10725, CVE-2020-10726).
  * 0001-vhost-check-log-mmap-offset-and-size-overflow.patch
  * 0002-vhost-fix-vring-index-check.patch
  * 0003-vhost-crypto-validate-keys-lengths.patch
  * 0004-vhost-fix-translated-address-not-checked.patch
  * 0005-vhost-fix-potential-memory-space-leak.patch
  * 0006-vhost-fix-potential-fd-leak.patch
* Wed Apr 29 2020 Jaime Caamaño Ruiz <jcaamano@suse.com>
- Update to v19.11.1. For a list of changes, check:
  * https://doc.dpdk.org/guides/rel_notes/release_19_11.html#new-features
- Removed patches no longer applying to the code base:
  * 0001-vhost-fix-possible-denial-of-service-on-SET_VRING_NU.patch
  * 0002-vhost-fix-possible-denial-of-service-by-leaking-FDs.patch
  * 0002-fix-cpu-compatibility.patch
- Rebased patches:
  * 0001-fix-cpu-compatibility.patch
* Mon Mar  2 2020 Stefan Weiberg <sweiberg@suse.com>
- Change constraint to ssse3 to fix build issues on x86_64 and i586
* Tue Nov 19 2019 Jaime Caamaño Ruiz <jcaamano@suse.com>
- Add version to the PMD driver directory to avoid loading previous
  version drivers (bsc#1157179).
- Update to 18.11.3 (bsc#1156146). For a list of fixes check:
  * https://doc.dpdk.org/guides-18.11/rel_notes/release_18_11.html#fixes
- Add patches to fix vulnerability where malicious container can trigger
  a denial of service (CVE-2019-14818, bsc#1156146)
  * 0001-vhost-fix-possible-denial-of-service-on-SET_VRING_NU.patch
  * 0002-vhost-fix-possible-denial-of-service-by-leaking-FDs.patch
- Removed patrches already included upstream:
  * dpdk-fix-implicit-fallthrough-warning.patch
* Mon Sep 30 2019 <jcaamano@suse.com>
- Changed to multibuild (bsc#1151455).
- Added dpdk-fix-implicit-fallthrough-warning.patch to address build error with
  recent kernels (bsc#1144704).
* Mon Jun 17 2019 ndas@suse.de
- Minor Update to 18.11.2
  * List of fixes can be found in
    https://doc.dpdk.org/guides-18.11/rel_notes/release_18_11.html#fixes
* Mon Apr 29 2019 ndas@suse.de
- Add missing libmnl-devel
* Fri Mar  8 2019 ndas@suse.de
- remove -Wno-error=array-bounds as its no longer needed
- disable i586 build because lack of sse support
* Fri Feb 22 2019 ndas@suse.de
- Add  0002-fix-cpu-compatibility.patch to address issue with older
  CPUs (bsc#1125961, bsc#1099474)
  [+ 0002-fix-cpu-compatibility.patch]
* Thu Jan 24 2019 ndas@suse.de
- Update to 18.11; some of the changes are(fate#325916, fate#325951 fate#326025, fate#326992, bsc#1134968, jira#SLE-4715) :
  * Added support for using externally allocated memory in DPDK.
  * Added check for ensuring allocated memory is addressable by devices.
  * Updated the C11 memory model version of the ring library.
  * Added NXP CAAM JR PMD.
  * Added support for GEN3 devices to Intel QAT driver.
  * Added Distributed Software Eventdev PMD.
  * Updated KNI kernel module, rte_kni library, and KNI sample application.
  * Add a new sample application for vDPA.
  * Updated mlx5 driver.
  * * Improved security of PMD to prevent the NIC from getting stuck when the application misbehaves.
  * * Reworked flow engine to supported e-switch flow rules (transfer attribute).
  * * Added support for header re-write(L2-L4), VXLAN encap/decap, count, match on TCP flags and multiple flow groups with e-switch flow rules.
  * * Added support for match on metadata, VXLAN and MPLS encap/decap with flow rules.
  * * Added support for RTE_ETH_DEV_CLOSE_REMOVE flag to provide better support for representors.
  * * Added support for meson build.
  * * Fixed build issue with PPC.
  * * Added support for BlueField VF.
  * * Added support for externally allocated static memory for DMA.
  all the changes can be viwed in http://doc.dpdk.org/guides/rel_notes/release_18_11.html
  [- 0001-enic-fix-Type-punning-and-strict-aliasing-warning.patch]
* Thu Oct 25 2018 ndas@suse.de
- Enable missed MLX PMDs for SLE12SP4 (bsc#1112307)
* Mon Sep 24 2018 Marco Varlese <marco.varlese@suse.com>
- Fixed a problem with ABI compatibility; API/ABI compatibility is
  guaranteed by DPDK upstream community across subsequent bug-fix
  releases. However, the .spec file broke it by defining the wrong
  version which included also the bug-fix release number.
- Fixed a naming issue with library: did not reflect soname
* Wed Aug 29 2018 marco.varlese@suse.com
- Fixed a syntax error affecting csh environment configuration(bsc#1102310)
* Mon Jun 18 2018 marco.varlese@suse.com
- Update to 18.02.2; some of the changes are:
  * Added function to allow releasing internal EAL resources on exit
  * Added igb, ixgbe and i40e ethernet driver to support RSS with flow API
  * Updated i40e driver to support PPPoE/PPPoL2TP
  * Added MAC loopback support for i40e
  * Added support of run time determination of number of queues per i40e VF
  * Updated mlx4/mlx5 driver
  * Added NVGRE and UDP tunnels support in Solarflare network PMD
  * Added AVF (Adaptive Virtual Function) net PMD
  * Added feature supports for live migration from vhost-net to vhost-user
  * Updated the AESNI-MB PMD
  * Updated the DPAA_SEC crypto driver to support rte_security
  * Added New eventdev Ordered Packet Distribution Library (OPDL) PMD
  * Added GRO support for VxLAN-tunneled packets
- Removed 0002-dpdk-eal-ppc-rte_smp_mb.patch since incorporated
  upstream
* Mon Apr 23 2018 marco.varlese@suse.com
- Update to 18.02.1
- Restrict untrusted guest to misuse virtio to corrupt
  host application(ovs-dpdk) memory which can lead all VM to lose
  connectivity(CVE-2018-1059,bsc#1089638).
  Changes:
  * Add deprecation notice for rte_vhost_gpa_to_vva()
  * Patch vhost-net and vhost-scsi examples
  * Fixes checkpatch warnings
  * Take VIRTIO_RING_F_EVENT_IDX into account when ring size (Tiwei)
  * Fix next chuncks translation access rights in Rx paths (Tiwei)
  * vhost: fix indirect descriptors table translation size
  * vhost: check all range is mapped when translating GPAs
  * vhost: introduce safe API for GPA translation
  * vhost: ensure all range is mapped when translating QVAs
  * vhost: add support for non-contiguous indirect descs tables
  * vhost: handle virtually non-contiguous buffers in Tx
  * vhost: handle virtually non-contiguous buffers in Rx
  * vhost: handle virtually non-contiguous buffers in Rx-mrg
  * examples/vhost: move to safe GPA translation API
  * examples/vhost_scsi: move to safe GPA translation API
  * vhost/crypto: move to safe GPA translation API
  * vhost: deprecate unsafe GPA translation API
* Fri Apr 20 2018 ndas@suse.de
- Enable MLX4/5 PMD only in Factory and >= SLES15
  It needs rdma-core >= v16.
* Tue Mar  6 2018 marco.varlese@suse.de
- Removed 0002-kni-fix-build-on-SLE12-SP3.patch since no longer referenced in .spec files
- Added 0002-dpdk-eal-ppc-rte_smp_mb.patch to fix an issue on ppc64le platforms with v18.02
- Updated to version 18.02; some of the changes include:
  * Added function to allow releasing internal EAL resources on exit
  * Added igb, ixgbe and i40e ethernet driver to support RSS with flow API
  * Updated i40e driver to support PPPoE/PPPoL2TP
  * Added MAC loopback support for i40e
  * Added support of run time determination of number of queues per i40e VF
  * Updated mlx5 driver
  * Updated mlx4 driver
  * Added NVGRE and UDP tunnels support in Solarflare network PMD
  * Added AVF (Adaptive Virtual Function) net PMD
  * Added feature supports for live migration from vhost-net to vhost-user
  * Updated the AESNI-MB PMD
  * Updated the DPAA_SEC crypto driver to support rte_security
  * Added Wireless Base Band Device (bbdev) abstraction
  * Added New eventdev Ordered Packet Distribution Library (OPDL) PMD
  * Added new pipeline use case for dpdk-test-eventdev application
  * Updated Eventdev sample application to support event devices based on capability
  * Added Rawdev, a generic device support library
  * Added new multi-process communication channel
  * Added GRO support for VxLAN-tunneled packets
  * Increased default Rx and Tx ring size in sample applications
  * Added new DPDK build system using the tools “meson” and “ninja” [EXPERIMENTAL]
* Wed Feb 28 2018 marco.varlese@suse.de
- The vm_power example does not work for ppc64le since it uses the
  IXGBE PMD driver which is not available for that platform(bsc#1082154):
  * Disable CONFIG_RTE_LIBRTE_POWER for the sample application;
  * Disable CONFIG_RTE_LIBRTE_IXGBE_PMD for the actual PMD driver;
* Tue Feb 27 2018 marco.varlese@suse.de
- Upgraded to latest stable release 17.11.1 (LTS): some of the fixes include:
  * location changes of the GPL and LGPL licenses;
  * net/mlx4:
  - fix drop flow resources leak
  * net/bnxt:
  - double increment of idx during Tx ring alloc
  - group info usage
  - check for ether type
  - size of Tx ring in HW
  - number of pools for RSS
  - return code in MAC address set
  - link speed setting with autoneg off
  * net/nfp:
  - MTU settings
  - jumbo settings
  - CRC strip check behaviour
  * net/sfc:
  - multicast address list copy memory leak
  - DMA memory leak after kvarg processing failure
  - fix label name to be consistent
  * net/i40e:
  - VLAN offload setting issue
  - FDIR input set conflict
  - FDIR rule confiliction issue
  - setting MAC address of VF
  - flow director Rx resource defect
  - warn when writing global registers
  - multiple driver support
  - interrupt conflict with multi-driver
  - Rx interrupt
  - check multi-driver option parsing
  - flow director filter
  * net/qede:
  - enable LRO over tunnels
  - reject config with no Rx queue
  - check tunnel L3 header
  - tunnel header size in Tx BD configuration
  - VF LRO tunnel configuration
  * net/mlx5:
  - Tx checksum offloads
  - un-supported RSS hash fields use
  - device operation type
  - pedantic compilation
  - fix pedantic compilation
  - flow item validation
  - flow RSS configuration
  - UAR remapping on non configured queues
  - secondary process verification
  - port stop by verify flows are still present
  - flow priority on queue action
* Mon Jan 15 2018 ndas@suse.de
- Enable(disabled by default) MLX4 and MLX5 pmd(fate#322609)
* Tue Jan  9 2018 marco.varlese@suse.de
- Upgraded to latest major 17.11(fate#322609); some of the fixes include:
  * Extended port_id range from uint8_t to uint16_t
  * Added a new driver for Marvell Armada 7k/8k devices
  * Updated mlx4 driver
  * Updated mlx5 driver
  * Added SoftNIC PMD
  * Added support for NXP DPAA Devices
  * Updated support for Cavium OCTEONTX Device
  * Added PF support to the Netronome NFP PMD
  * Updated bnxt PMD
  * Added bus agnostic functions to cryptodev for PMD initialization
  * Updated QAT crypto PMD
  * Updated the AESNI MB PMD
  * Updated the OpenSSL PMD
  * Added NXP DPAA SEC crypto PMD
  * Add new benchmarking mode to dpdk-test-crypto-perf application
  * Added IOMMU support to libvhost-user
  * Added the Generic Segmentation Offload Library
  * Added the Flow Classification Library
- Removed 0002-kni-fix-build-on-SLE12-SP3.patch since patch merged upstream and available in 17.11
* Fri Dec 22 2017 marco.varlese@suse.de
- Added missing supported broadcom chipset family Broadcom NetXtreme II BCM57810
* Mon Dec 11 2017 marco.varlese@suse.de
- Upgraded to latest stable 17.08.1; some of the fixes include:
  * net/qede: disable per-VF Tx switching feature
  * revert "net/virtio: flush Rx queues on start"
  * various fixes for mlx5 PMD drivers
  * various fixes for bnxt PMD drivers
  * various fixes for i40e PMD drivers
  * various fixes for crypto PMD drivers
  * testpmd: fix for non-consecutive ports
  * ethdev: fix ABI version
* Wed Nov 15 2017 mchandras@suse.de
- Add missing libelf-devel dependency
* Mon Sep  4 2017 ndas@suse.de
- Updated to 17.08(bsc#1050250, bsc#1046598, fate#322913, fate#322608)
  Some of the new features are listed below:
  * Increase minimum x86 ISA version to SSE4.2
  * Added Fail-Safe PMD
  * Added support for generic flow API (rte_flow) on igb NICs
  * Added support for generic flow API (rte_flow) on enic
  * Added support for Chelsio T6 family of adapters
  * Added latency and performance improvements for cxgbe
  * Updated mlx5 driver
  * Added NXP DPAA2 Eventdev PMD
  * Added dpdk-test-eventdev test application
  * from 17.05:
  * Added mbuf raw free API
  * Added free Tx mbuf on demand API
  * Added VFIO hotplug support
  * Added PowerPC support for i40e and its vector PMD
  * Added VF max bandwidth setting in i40e
  * Added LiquidIO network PMD
  * Added support for NXP DPAA2 Network PMD
  * Added support for NXP DPAA2 - FSLMC bus
  * Added support for the Wind River Systems AVP PMD
  * Added vmxnet3 version 3 support
  * Added MTU feature support to Virtio and Vhost
  * Added event driven programming model library (rte_eventdev)
  * Added Software Eventdev PMD
  * Added Cavium OCTEONTX Eventdev PMD
  * Added NXP DPAA2 SEC crypto PMD
  * from 17.02:
  * Added generic EAL API for I/O device memory read/write operations
  * Added VF Daemon (VFD) for i40e. - EXPERIMENTAL
  * Added generic flow API (rte_flow)
  * Added APIs for MACsec offload support to the ixgbe PMD
  * Added Solarflare libefx-based network PMD.
  * Added support for Mellanox ConnectX-5 adapters (mlx5)
  * Added ARMv8 crypto PMD
  * Added crypto performance test application
  * more details can be found in
    http://dpdk.org/doc/guides/rel_notes/release_17_08.html
    http://dpdk.org/doc/guides/rel_notes/release_17_05.html
    http://dpdk.org/doc/guides/rel_notes/release_17_02.html
    [-0002-kni-define-HAVE_VF_VLAN_PROTO-for-SLES12SP3.patch
  - 0003-kni-define-HAVE_TRANS_START_HELPER-for-SLES12SP3.patch
  - 0004-net-thunderx-sync-mailbox-definitions-with-Linux-PF-.patch
  - 0005-kni-fix-build-with-gcc-7.1.patch
  - 0006-kni-fix-ethtool-build-with-kernel-4.11.patch
  - 0007-igb_uio-switch-to-new-irq-function-for-MSI-X.patch]
- Use updated patch to enable HAVE_TRANS_START_HELPER for SLE12SP3(bsc#1031705).
  [+ 0002-kni-fix-build-on-SLE12-SP3.patch]
* Fri Aug 25 2017 marco.varlese@suse.com
- Enabled CONFIG_RTE_MAJOR_ABI: libs SONAME equal the DPDK release version
* Fri Aug 18 2017 marco.varlese@suse.com
- Split libs into a subpackage to provide multiple installable versions on same sytem
* Tue Jul 18 2017 ndas@suse.de
- Do not use obsolete pci_enable_msix for() kernel > 4.8
  [+0006-kni-fix-ethtool-build-with-kernel-4.11.patch,
  +0007-igb_uio-switch-to-new-irq-function-for-MSI-X.patch]
* Wed Jun 14 2017 ndas@suse.de
- Updated to 16.11.2 which provide bug fixes as below(fate#321541):
  * mbuf: fix missing includes in exported header
  * eal: fix debug macro redefinition
  * net/nfp: fix packet/data length conversion
  * net/i40e: fix setup when bulk is disabled
  * pci: fix device registration on FreeBSD
  * net/i40e: ensure vector mode is not used with QinQ
  * nic_uio: fix device binding at boot
  * net/bnx2x: fix transmit queue free threshold
  * net/vmxnet3: fix queue size changes
  * kni: fix build with kernel 4.11
  * kni: fix possible memory leak
  * kni: fix crash caused by freeing mempool
  * net/i40e: fix allocation check
  * net/virtio: fix crash when closing twice
  * net/ixgbevf: set xstats id values
  * net/i40e: fix hash input set on X722
  * eal/linux: fix build with glibc 2.25
  * net/i40e: fix incorrect packet index reference
  * net/thunderx: fix 32-bit build
  * net/thunderx: fix build on FreeBSD
  * net/thunderx: fix deadlock in Rx path
  * net/ixgbe: fix setting MTU on stopped device
  * vfio: fix secondary process start
  * net/virtio-user: fix address on 32-bit system
  * net/virtio: fix MSI-X for modern devices
  * net/virtio: fix link status always down
  * net/ixgbe: fix multi-queue mode check in SRIOV mode
  * net/i40e/base: fix potential out of bound array access
  * vhost: fix false sharing
  * net/thunderx: fix stats access out of bounds
  * net/virtio: disable LSC interrupt if MSIX not enabled
  * net/i40e: fix mbuf alloc failed counter
  * net: fix stripped VLAN flag for offload emulation
  * vfio: fix disabling INTx
  * net/igb: fix VF MAC address setting
  * net/igb: fix VF MAC address setting
  * net/ixgbe: fix VF Rx mode for allmulticast disabled
  * net/bonding: fix updating slave link status
  * net/virtio-user: fix overflow
  * net/i40e: fix TC bitmap of VEB
  * net/ixgbe/base: fix build error
  * net/ixgbe: fix Rx queue blocking issue
  * net/ixgbe: fix all queues drop setting of DCB
  * net/ixgbe: fix TC bandwidth setting
  more details can be found in
  http://dpdk.org/ml/archives/stable/2017-May/001809.html
  [- 0005-kni-fix-build-with-kernel-4.11.patch]
- use default gcc which is now gcc7 (bsc#1042372)
  [+0005-kni-fix-build-with-gcc-7.1.patch]
* Tue May 23 2017 mchandras@suse.de
- Add upstream patch to fix building against linux kernel 4.11
  [+0005-kni-fix-build-with-kernel-4.11.patch]
* Tue Apr 25 2017 ndas@suse.de
- sync mailbox definitions with Linux PF driver(bsc#1035993)
  [+0004-net-thunderx-sync-mailbox-definitions-with-Linux-PF-.patch]
* Tue Apr 18 2017 ndas@suse.de
- Enable HAVE_TRANS_START_HELPER for SLE12SP3(bsc#1031705).
  [+0003-kni-define-HAVE_TRANS_START_HELPER-for-SLES12SP3.patch]
* Tue Apr  4 2017 ndas@suse.de
- Fix dpdk KMP build fails(bsc#1031750)
- enable igb_uio kernel module(fate#322394)
- update kernel version for SLES12SP3 4.4.59 for bsc#1031705
  [*0002-kni-define-HAVE_VF_VLAN_PROTO-for-SLES12SP3.patch]
* Thu Mar 30 2017 ndas@suse.de
- Enable HAVE_VF_VLAN_PROTO for SLE12SP3(bsc#1031705).
  [+0002-kni-define-HAVE_VF_VLAN_PROTO-for-SLES12SP3.patch]
* Mon Mar 20 2017 ndas@suse.de
- Disable dpdk-kmp package for ix86.
* Fri Mar  3 2017 ndas@suse.de
- Upgrade to LTS release of 16.11 which contains fixes below(fate#321541):
  * app/test: fix symmetric session free in crypto perf tests
  * app/testpmd: fix check for invalid ports
  * app/testpmd: fix static build link ordering
  * crypto/aesni_gcm: fix IV size in capabilities
  * crypto/aesni_gcm: fix J0 padding bytes
  * crypto/aesni_mb: fix incorrect crypto session
  * crypto/openssl: fix extra bytes written at end of data
  * crypto/openssl: fix indentation in guide
  * crypto/qat: fix IV size in capabilities
  * crypto/qat: fix to avoid buffer overwrite in OOP case
  * cryptodev: fix crash on null dereference
  * cryptodev: fix loop in device query
  * devargs: reset driver name pointer on parsing failure
  * drivers/crypto: fix different auth/cipher keys
  * ethdev: check maximum number of queues for statistics
  * ethdev: fix extended statistics name index
  * ethdev: fix port data mismatched in multiple process model
  * ethdev: fix port lookup if none
  * ethdev: remove invalid function from version map
  * examples/ethtool: fix driver information
  * examples/ethtool: fix querying non-PCI devices
  * examples/ip_pipeline: fix coremask limitation
  * examples/ip_pipeline: fix parsing of pass-through pipeline
  * examples/l2fwd-crypto: fix overflow
  * examples/vhost: fix calculation of mbuf count
  * examples/vhost: fix lcore initialization
  * mempool: fix API documentation
  * mempool: fix stack handler dequeue
  * net/af_packet: fix fd use after free
  * net/bnx2x: fix Rx mode configuration
  * net/cxgbe/base: initialize variable before reading EEPROM
  * net/cxgbe: fix parenthesis on bitwise operation
  * net/ena: fix setting host attributes
  * net/enic: fix hardcoding of some flow director masks
  * net/enic: fix memory leak with oversized Tx packets
  * net/enic: remove unnecessary function parameter attributes
  * net/i40e: enable auto link update for 25G
  * net/i40e: fix Rx checksum flag
  * net/i40e: fix TC bandwidth definition
  * net/i40e: fix VF reset flow
  * net/i40e: fix checksum flag in x86 vector Rx
  * net/i40e: fix crash in close
  * net/i40e: fix deletion of all macvlan filters
  * net/i40e: fix ethertype filter on X722
  * net/i40e: fix link update delay
  * net/i40e: fix logging for Tx free threshold check
  * net/i40e: fix segment number in reassemble process
  * net/i40e: fix wrong return value when handling PF message
  * net/i40e: fix xstats value mapping
  * net/i40evf: fix casting between structs
  * net/i40evf: fix reporting of imissed packets
  * net/ixgbe: fix blocked interrupts
  * net/ixgbe: fix received packets number for ARM
  * net/ixgbe: fix received packets number for ARM NEON
  * net/ixgbevf: fix max packet length
  * net/mlx5: fix RSS hash result for flows
  * net/mlx5: fix Rx packet validation and type
  * net/mlx5: fix Tx doorbell
  * net/mlx5: fix endianness in Tx completion queue
  * net/mlx5: fix inconsistent link status
  * net/mlx5: fix leak when starvation occurs
  * net/mlx5: fix link status query
  * net/mlx5: fix memory leak when parsing device params
  * net/mlx5: fix missing inline attributes
  * net/mlx5: fix updating total length of multi-packet send
  * net/mlx: fix IPv4 and IPv6 packet type
  * net/nfp: fix VLAN offload flags check
  * net/nfp: fix typo in Tx offload capabilities
  * net/pcap: fix timestamps in output pcap file
  * net/qede/base: fix FreeBSD build
  * net/qede: add vendor/device id info
  * net/qede: fix PF fastpath status block index
  * net/qede: fix filtering code
  * net/qede: fix function declaration
  * net/qede: fix per queue statisitics
  * net/qede: fix resource leak
  * net/vhost: fix socket file deleted on stop
  * net/vhost: fix unix socket not removed as closing
  * net/virtio-user: fix not properly reset device
  * net/virtio-user: fix wrongly get/set features
  * net/virtio: fix build without virtio-user
  * net/virtio: fix crash when number of virtio devices > 1
  * net/virtio: fix multiple process support
  * net/virtio: fix performance regression due to TSO
  * net/virtio: fix rewriting LSC flag
  * net/virtio: fix wrong Rx/Tx method for secondary process
  * net/virtio: optimize header reset on any layout
  * net/virtio: store IO port info locally
  * net/virtio: store PCI operators pointer locally
  * net/vmxnet3: fix Rx deadlock
  * pci: fix check of mknod
  * pmdinfogen: fix endianness with cross-compilation
  * pmdinfogen: fix null dereference
  * sched: fix crash when freeing port
  * usertools: fix active interface detection when binding
  * vdev: fix detaching with alias
  * vfio: fix file descriptor leak in multi-process
  * vhost: allow many vhost-user ports
  * vhost: do not GSO when no header is present
  * vhost: fix dead loop in enqueue path
  * vhost: fix guest/host physical address mapping
  * vhost: fix long stall of negotiation
  * vhost: fix memory leak
* Fri Feb 24 2017 ndas@suse.de
- Fix broken dpdk-pmd/* soft links(bsc#1026804).
* Thu Feb 16 2017 ndas@suse.de
- Do not disable cryptodev as EXPREMENTAL tag has been removed.
- Remove CONFIG_RTE_LIBRTE_MBUF_OFFLOAD as cryptodev is not depending
  on it anymore and its removed from the upstream.
* Fri Feb 10 2017 ndas@suse.de
- Enable rte_kni kernel module for dpdk(fate#322394).
  [+preamble]
- Build dpdk-thunderx only for aarch64
* Thu Feb  2 2017 ndas@suse.de
- Update to version 16.11(fate#321541). Some of the new features are listed below:
  * Added software parser for packet type.
  * Improved offloads support in mbuf.
  * Added vhost-user dequeue zero copy support.
  * Added vhost-user indirect descriptors support.
  * Added vhost PMD xstats.
  * Added virtio NEON support for ARM.
  * Updated the ixgbe base driver.
  * Added APIs for VF management to the ixgbe PMD.
  * Updated the enic driver.
  * Added openssl PMD.
  * Added support for new gcc -march option.
  Detailed changes can be obtained from http://dpdk.org/doc/guides/rel_notes/release_16_11.html
- Resolved fixes in the updated versions are :
  * enic: Fixed several flow director issues.
  * enic: Fixed inadvertent setting of L4 checksum ptype on ICMP packets.
  * enic: Fixed high driver overhead when servicing Rx queues beyond the first.
* Fri Jan 20 2017 ndas@suse.de
- Added gcc-6 as default compiler for CRC/mtune & other optimizations.
- Fix possible parallel installation of dpdk subpackages.
* Wed Jan  4 2017 ndas@suse.de
- Add pre_checkin.sh to generate the dpdk-thunderx.spec file
* Mon Dec 12 2016 marco.varlese@suse.com
- Fixed paths using %%{name} to have the dpdk.spec aligned with dpdk-thunderx.spec
* Mon Dec 12 2016 marco.varlese@suse.com
- Added back in all the architectures to keep .spec files aligned
  * Driving thunderx platform architectural dependency via the ExclusiveArch tag
* Mon Dec 12 2016 mvarlese@suse.com
- Added support to build code for Thunderx platform(fate#321960).
- Introduced new dpdk-thunderx.spec file:
  * Removed architectures not supporting Thunderx platform (e.g. x86)
  * Added dependency on gcc v5.0 for armv8a-crc
* Wed Nov 30 2016 mchandras@suse.de
- Update to version 16.07.2. Some of the fixes are listed below:
  * ethdev: prevent duplicate event callback
  * hash: fix bucket size usage
  * hash: fix unlimited cuckoo path
  * lpm: fix freeing memory
  * lpm: fix freeing unused sub-table on rule delete
  * mempool: fix leak if populate fails
  * mempool: fix search of maximum contiguous pages
  * pci: fix probing error if no driver found
  * net/bnx2x: fix maximum PF queues
  * net/bnxt: fix bit shift size
  * net/bnxt: fix crash when closing
  * net/enic: fix Rx queue index when not using Rx scatter
  * net/enic: fix crash on MTU update or Rx queue reconfigure
  * net/enic: fix crash with removed flow director filters
  * net/enic: fix max packet length check
  * net/enic: fix multi-queue Rx performance
  * net/enic: revert truncated packets counter fix
  * net/fm10k: fix VF Tx queue initialization
  * net/i40e: fix Rx hang when disable LLDP
  * net/ixgbe: fix VF registers
  * net/thunderx: fix Tx checksum handling
  * [The list of changes is rather long so please consult the following
    resources for the complete list of new features, bugfixes and other
    changes in this release:
  - http://dpdk.org/doc/guides-16.07/rel_notes/release_16_07.html#id2]
* Thu Nov 24 2016 mchandras@suse.de
- Update to version 16.07.1. Some of the fixes are listed below:
  * contigmem: zero all pages during mmap
  * crypto/null: fix key size increment value
  * hash: fix false zero signature key hit lookup
  * mem: fix crash on hugepage mapping error
  * mbuf: fix error handling on pool creation
  * net/e1000: fix returned number of available Rx descriptors
  * net/enic: fix freeing memory for descriptor ring
  * net/i40e: fix dropping packets with ethertype 0x88A8
  * net/i40e: fix mbuf leak during Rx queue release
  * net/i40e: fix null pointer dereferences when using VMDq+RSS
  * net/ixgbe/base: fix possible corruption of shadow RAM
  * net/ixgbe: fix VF reset to apply to correct VF
  * net/virtio_user: fix error management during init
  * [The list of changes is rather long so please consult the following
    resources for the complete list of new features, bugfixes and other
    changes in this release:
  - http://dpdk.org/doc/guides-16.07/rel_notes/release_16_07.html#fixes-in-16-07-01-stable-release]
* Thu Oct  6 2016 mchandras@suse.de
- Drop code for generating our own linker script.
  * Commit 948fd64befc3 (" mk: replace the combined library with a
    linker script") added upstream support for building and installing
    a linker script so we drop our code from the spec file which
    generated a much larger and possibly broken linker script resulting
    to linking issues (boo#1002534)
* Wed Aug 10 2016 ndas@suse.de
- Update to version 16.07. Some of the new features are listed below:
  * Removed the mempool cache memory if caching is not being used.
  * Added mempool external cache for non-EAL thread.
  * Changed the memory allocation scheme in the mempool library.
  * Added a new driver for Broadcom NetXtreme-C devices.
  * Added a new driver for ThunderX nicvf devices.
  * Added mailbox interrupt support for ixgbe and igb VFs.
  * Updated the ixgbe base driver.
  * Updated the i40e base driver.
  * Updated the enic driver.
  * Updated the mlx5 driver.
  * Added support for virtio on IBM POWER8.
  * Added support for Virtio in containers.
  * Added vhost-user client mode.
  * Added NSH packet recognition in i40e.
  * Added AES-CTR support to AESNI MB PMD.
  * Added AES counter mode support for Intel QuickAssist devices.
  * Added KASUMI SW PMD.
  * Added multi-writer support for RTE Hash with Intel TSX.
  * Improved IP Pipeline Application.
  * Added keepalive enhancements.
  * Added packet capture framework.
  * Added floating VEB support for i40e PF driver.
  * Added support for live migration of a VM with SRIOV VF.
  * [The list of changes is rather long so please consult the following
    resources for the complete list of new features, bugfixes and other
    changes in this release:
  - http://dpdk.org/doc/guides/rel_notes/release_16_07.html
  - http://dpdk.org/browse/dpdk/tree/doc/guides/rel_notes/release_16_07.rst
  - Or the doc/guides/rel_notes/release_16_07.rst file in the released
    tarball.]
- Removed patches that are already avilable in dpdk-16.07
  [ -0002-examples-ip_pipeline-fix-implicit-declaration-of-fun.patch
  - 0003-mk-fix-external-shared-library-dependencies-of-libraries.patch
  - 0004-54f9e32-vhost-handle-dirty-pages-logging-request.patch
  - 0005-d293dac-vhost-claim-support-of-guest-announce.patch
  - 0006-d639996-vhost-enable-log_shmfd-protocol-feature.patch
  - 0007-ixgbe-fix-VLAN-filter-missing-brackets.patch
  - 0008-app-testpmd-handle-SIGINT-and-SIGTERM.patch
  - 0009-bonding-copy-entire-config-structure-in-mode-4.patch
  - 0010-bonding-fix-active-slaves-with-no-primary.patch
  - 0011-bonding-do-not-ignore-multicast-in-mode-4.patch
  - 0012-bonding-do-not-activate-slave-twice.patch
  - 0013-bonding-fix-crash-when-no-slave-device.patch
  - 0014-bonding-fix-detach-of-bonded-device.patch
  - 0015-bonding-fix-detach-of-slave-devices.patch
  - 0016-eal-linux-support-built-in-kernel-modules.patch
  - 0017-examples-l3fwd-handle-SIGINT-and-SIGTERM.patch
  - 0018-fm10k-fix-VLAN-flag-in-scattered-Rx.patch
  - 0019-i40e-base-fix-driver-load-failure.patch
  - 0020-i40e-base-fix-missing-check-for-stopped-admin-queue.patch
  - 0021-i40e-fix-inverted-check-for-no-refcount.patch
  - 0022-i40e-fix-overflow.patch
  - 0023-i40e-fix-VLAN-filtering.patch
  - 0024-mempool-fix-leak-when-creation-fails.patch
  - 0025-pcap-fix-captured-frame-length.patch
  - 0026-port-fix-crash-for-ethdev-writer-nodrop.patch
  - 0027-port-fix-crash-for-ring-writer-nodrop.patch
  - 0028-tools-fix-unbinding-failure-handling.patch
  - 0029-tools-support-Python-3-in-bind-script.patch
  - 0030-tools-support-binding-to-built-in-kernel-modules.patch
  - 0031-vhost-fix-leak-of-fds-and-mmaps.patch
  - 0032-virtio-fix-crash-in-statistics-functions.patch
  - 0033-virtio-fix-descriptors-pointing-to-the-same-buffer.patch
  - 0034-virtio-fix-restart.patch
  - 0035-PAGE_SIZE-constant-is-not-defined-on-ARM-since-multi.patch
  - 0036-examples-fix-build-dependencies.patch
  - 0037-examples-ethtool-fix-build.patch
  - 0099-mk-fix-gcc-5-version-on-suse.patch
  - 0100-kni-fix-build-with-gcc-6.patch
  - 0101-ixgbe-fix-uninitialized-warning.patch
  - 0102-ixgbe-fix-constant-sign-in-left-shift-operator.patch
  - 0103-e1000-base-Add-missing-braces-to-the-if-statements.patch
  - 0104-igb-fix-constant-sign-in-left-shift-operator.patch
  - 0105-e1000-fix-missing-link-interrupt-check-brackets.patch
  - 0106-app-test-fix-missing-brackets.patch
  - 0107-examples-ip_pipeline-use-unsigned-constants-for-left.patch
  ]
- Created soft link for dpdk_proc_info and dpdk_nic_bind(from dpdk-procinfo, dpdk-devbind) to keep compatibility.
- Added a new binary dpdk-pdump dpdk-procinfo
* Thu Jul 28 2016 ndas@suse.de
- Add _constraints file to force build dpdk with sse3 enabled x86 machine(bsc#993462).
- Enable compilation for  ppc64le with the help of Rüdiger(ro@suse.de).
- Enable example package for aarch64 using Rüdiger(ro@suse.de) changes.
- Do not enable PMD_RING on ppc64le (missing rte_eth_from_rings).
- Disable examples that need LPM which is disabled on non-x86.
  [+0036-examples-fix-build-dependencies.patch,
  +0037-examples-ethtool-fix-build.patch,
  +_constraints]
* Mon Jul 11 2016 ndas@suse.de
- Added support for aarch64 compilation.
  [+0035-PAGE_SIZE-constant-is-not-defined-on-ARM-since-multi.patch]
- Disabled aarch64 dpdk-examples package for the time being as it
  contains lots of Intel specific code.
- Added proper "Group" field for the subpackages .
* Thu Jun 23 2016 mchandras@suse.de
- Add upstream patches to fix building with gcc >= 6
  * 0100-kni-fix-build-with-gcc-6.patch
  * 0101-ixgbe-fix-uninitialized-warning.patch
  * 0102-ixgbe-fix-constant-sign-in-left-shift-operator.patch
  * 0103-e1000-base-Add-missing-braces-to-the-if-statements.patch
  * 0104-igb-fix-constant-sign-in-left-shift-operator.patch
  * 0105-e1000-fix-missing-link-interrupt-check-brackets.patch
  * 0106-app-test-fix-missing-brackets.patch
  * 0107-examples-ip_pipeline-use-unsigned-constants-for-left.patch
* Tue Jun 14 2016 ndas@suse.de
- Removed unwanted files(bsc#984437).
* Thu Jun  9 2016 ndas@suse.de
- Added missing GPL-2.0 and LGPL-2.1 licenses.
* Wed Jun  1 2016 mchandras@suse.de
- Update tarball URL.
* Fri May 27 2016 ndas@suse.de
- Applied all the fixes recommended by upstream for
  v2.2 stable release(bsc#981996).
  [+0008-app-testpmd-handle-SIGINT-and-SIGTERM.patch,
  +0009-bonding-copy-entire-config-structure-in-mode-4.patch,
  +0010-bonding-fix-active-slaves-with-no-primary.patch,
  +0011-bonding-do-not-ignore-multicast-in-mode-4.patch,
  +0012-bonding-do-not-activate-slave-twice.patch,
  +0013-bonding-fix-crash-when-no-slave-device.patch,
  +0014-bonding-fix-detach-of-bonded-device.patch,
  +0015-bonding-fix-detach-of-slave-devices.patch,
  +0016-eal-linux-support-built-in-kernel-modules.patch,
  +0017-examples-l3fwd-handle-SIGINT-and-SIGTERM.patch,
  +0018-fm10k-fix-VLAN-flag-in-scattered-Rx.patch,
  +0019-i40e-base-fix-driver-load-failure.patch,
  +0020-i40e-base-fix-missing-check-for-stopped-admin-queue.patch,
  +0021-i40e-fix-inverted-check-for-no-refcount.patch,
  +0022-i40e-fix-overflow.patch,
  +0023-i40e-fix-VLAN-filtering.patch,
  +0024-mempool-fix-leak-when-creation-fails.patch,
  +0025-pcap-fix-captured-frame-length.patch,
  +0026-port-fix-crash-for-ethdev-writer-nodrop.patch,
  +0027-port-fix-crash-for-ring-writer-nodrop.patch,
  +0028-tools-fix-unbinding-failure-handling.patch,
  +0029-tools-support-Python-3-in-bind-script.patch,
  +0030-tools-support-binding-to-built-in-kernel-modules.patch,
  +0031-vhost-fix-leak-of-fds-and-mmaps.patch,
  +0032-virtio-fix-crash-in-statistics-functions.patch,
  +0033-virtio-fix-descriptors-pointing-to-the-same-buffer.patch,
  +0034-virtio-fix-restart.patch]
* Wed May 11 2016 mchandras@suse.de
- Use fdupes to manage duplicate files
* Thu Apr 28 2016 ndas@suse.de
- Create DPDK packages for 32 bit x86(bsc#977639).
* Wed Apr 27 2016 mchandras@suse.de
- Add upstream patch for the ixgbe driver
  * 0007-ixgbe-fix-VLAN-filter-missing-brackets.patch: Fix VLAN
    filtering logic by adding the missing brackets in the 'if' statement.
* Tue Apr 19 2016 ndas@suse.de
- DPDK is most common vhost-user backend, Adding upstream patches to
  help qemu vm live migration with vhost-user (fate#320713).
  [+ 0004-54f9e32-vhost-handle-dirty-pages-logging-request.patch
  + 0005-d293dac-vhost-claim-support-of-guest-announce.patch
  + 0006-d639996-vhost-enable-log_shmfd-protocol-feature.patch]
* Wed Apr 13 2016 mchandras@suse.de
- Move the combined library back to the devel package (bsc#975123)
  Ever since we dropped the CONFIG_RTE_BUILD_COMBINE_LIBS=y option, the
  libdpdk.so is no longer a shared object but rather a linker script
  generated by the spec file. This means that it is only used during
  linking and the linker will add the individual DPDK libraries to the
  DT_NEEDED tag on the dependent binaries.
* Tue Apr 12 2016 mchandras@suse.de
- Fix shared linking against libdpdk.so (bsc#975123)
  * Restore the 0003-mk-fix-external-shared-library-dependencies-of-libraries.patch
    patch which sets the correct dependencies for the shared libraries.
  * Drop CONFIG_RTE_BUILD_COMBINE_LIBS since a custom linker script
    is used to create and install a more lightweight version of libdpdk.so.
  * Include the combined libdpdk.so library to the regular package since it
    is also necessary during runtime.
* Mon Apr 11 2016 ndas@suse.de
- Removed unwnated patch and reformated patch file names(bsc#974903).
  [- dpdk-2.2-dtneeded.patch,
  - dpdk-2.2-examples.patch,
  - enic-pun-fix.patch,
  - dpdk-2.2-warningflags.patch,
  + 0001-enic-fix-Type-punning-and-strict-aliasing-warning.patch
  + 0002-examples-ip_pipeline-fix-implicit-declaration-of-fun.patch]
- Added CONFIG_RTE_BUILD_COMBINE_LIBS flags to club all all *.so into
  one library
* Mon Mar 21 2016 nirmoy.das@suse.com
- Intial version 2.2.0(fate#319169)
